Welcome to PRIMAP2's documentation!
======================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   readme
   installation
   data_format_examples
   usage
   special_usage
   data_reading
   datalad
   interchange_format_examples
   data_format_details
   interchange_format_details
   development
   credits
   api
   changelog

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
